@@ -627,7 +627,6 @@ geom_violin = make_ggplot2_binding("geom_violin")
 geom_vline = make_ggplot2_binding("geom_vline")
 get_alt_text = make_ggplot2_binding("get_alt_text")
 get_element_tree = make_ggplot2_binding("get_element_tree")
-ggplot = make_ggplot2_binding("ggplot")
 ggplot_add = make_ggplot2_binding("ggplot_add")
 ggproto = make_ggplot2_binding("ggproto")
 ggproto_parent = make_ggplot2_binding("ggproto_parent")
@@ -647,8 +646,6 @@ guide_train = make_ggplot2_binding("guide_train")
 guide_transform = make_ggplot2_binding("guide_transform")
 guides = make_ggplot2_binding("guides")
 has_flipped_aes = make_ggplot2_binding("has_flipped_aes")
-is.Coord = make_ggplot2_binding("is.Coord")
-is.ggproto = make_ggplot2_binding("is.ggproto")
 label_both = make_ggplot2_binding("label_both")
 label_bquote = make_ggplot2_binding("label_bquote")
 label_context = make_ggplot2_binding("label_context")
